@@ -7,38 +7,32 @@
 // INCLUDES
 
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 #include "DownloadManager.hpp"
 #include "ConfigVar.hpp"
 #include "OptionContainer.hpp"
 #include "ConnectionHandler.hpp"
 #include "RegExp.hpp"
+#include "Logger.hpp"
 
 #include <iostream>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <syslog.h>
 
 // GLOBALS
 
-extern bool is_daemonised;
 extern OptionContainer o;
-extern thread_local std::string thread_id;
 
 extern dmcreate_t defaultdmcreate;
 
 // find the class factory functions for any DM plugins we've been configured to build
 
-#ifdef ENABLE_FANCYDM
 extern dmcreate_t fancydmcreate;
-#endif
 
-#ifdef ENABLE_TRICKLEDM
 extern dmcreate_t trickledmcreate;
-#endif
 
 // IMPLEMENTATION
 
@@ -48,36 +42,13 @@ extern dmcreate_t trickledmcreate;
 
 // constructor
 DMPlugin::DMPlugin(ConfigVar &definition)
-    : alwaysmatchua(false), cv(definition), mimelistenabled(false), extensionlistenabled(false)
+    : alwaysmatchua(false), cv(definition)
 {
 }
 
 // default initialisation procedure
 int DMPlugin::init(void *args)
 {
-    bool lastplugin = *((bool *)args);
-    if (!lastplugin) {
-        // compile regex for matching supported user agents
-        String r(cv["useragentregexp"]);
-        if (r.length() > 0) {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "useragent regexp: " << r << std::endl;
-#endif
-            ua_match.comp(r.toCharArray());
-        } else {
-// no useragent regex? then default to .*
-#ifdef DGDEBUG
-            std::cerr << thread_id << "no useragent regular expression; defaulting to .*" << std::endl;
-#endif
-            alwaysmatchua = true;
-        }
-        if (!readStandardLists())
-            return -1;
-    }
-#ifdef DGDEBUG
-    else
-        std::cerr << thread_id << "Fallback DM plugin; no matching options loaded" << std::endl;
-#endif
     return 0;
 }
 
@@ -89,7 +60,7 @@ bool DMPlugin::sendLink(Socket &peersock, String &linkurl, String &prettyurl)
     message += "<a href=\"" + linkurl + "\">" + prettyurl + "</a></p></body></html>\n";
     return peersock.writeString(message.toCharArray());
 }
-
+#ifdef NOTDEF
 // default method for deciding whether we will handle a request
 bool DMPlugin::willHandle(HTTPHeader *requestheader, HTTPHeader *docheader)
 {
@@ -105,17 +76,18 @@ bool DMPlugin::willHandle(HTTPHeader *requestheader, HTTPHeader *docheader)
     bool matchedmime = false;
     if (mimelistenabled) {
         mimetype = docheader->getContentType();
-#ifdef DGDEBUG
-        std::cerr << thread_id << "mimetype: " << mimetype << std::endl;
-#endif
+        DEBUG_dwload("mimetype: ", mimetype);
         String lc;
         if (mimetypelist.findInList(mimetype.toCharArray(), lc) == NULL) {
             if (!extensionlistenabled)
                 return false;
         } else
-            matchedmime = true;
+            matchedmime = true;    
+    } else {
+        DEBUG_dwload("NO mimelistenabled!");
     }
 
+
     if (extensionlistenabled && !matchedmime) {
         // determine the extension
         String path(requestheader->decode(requestheader->getUrl()));
@@ -147,18 +119,21 @@ bool DMPlugin::willHandle(HTTPHeader *requestheader, HTTPHeader *docheader)
                 }
             }
         }
-#ifdef DGDEBUG
-        std::cerr << thread_id << "extension: " << extension << std::endl;
-#endif
+        DEBUG_dwload("extension: ", extension);
         // check the extension list
         String lc;
         if (!extension.contains(".") || (extensionlist.findEndsWith(extension.toCharArray(), lc) == NULL))
             return matchedmime;
+    } else {
+        DEBUG_dwload("NO extensionlistenabled!");
     }
 
+
     return true;
 }
+#endif
 
+#ifdef NOTDEF
 // read in all the lists of various things we wish to handle
 bool DMPlugin::readStandardLists()
 {
@@ -167,11 +142,8 @@ bool DMPlugin::readStandardLists()
 
     String filename(cv["managedmimetypelist"]);
     if (filename.length() > 0) {
-        if (!mimetypelist.readItemList(filename.toCharArray(), false, 0)) {
-            if (!is_daemonised) {
-                std::cerr << thread_id << "Error opening managedmimetypelist" << std::endl;
-            }
-            syslog(LOG_ERR, "Error opening managedmimetypelist");
+        if (!mimetypelist.readItemList(filename.toCharArray(),"", false, 0)) {
+            E2LOGGER_error("Error opening managedmimetypelist");
             return false;
         }
         mimetypelist.doSort(false);
@@ -182,11 +154,8 @@ bool DMPlugin::readStandardLists()
 
     filename = cv["managedextensionlist"];
     if (filename.length() > 0) {
-        if (!extensionlist.readItemList(filename.toCharArray(), false, 0)) {
-            if (!is_daemonised) {
-                std::cerr << thread_id << "Error opening managedextensionlist" << std::endl;
-            }
-            syslog(LOG_ERR, "Error opening managedextensionlist");
+        if (!extensionlist.readItemList(filename.toCharArray(), "", false, 0)) {
+            E2LOGGER_error("Error opening managedextensionlist");
             return false;
         }
         extensionlist.doSort(false);
@@ -197,6 +166,7 @@ bool DMPlugin::readStandardLists()
 
     return true;
 }
+#endif
 
 // take in a DM plugin configuration file, find the DMPlugin descendent matching the value of plugname, and store its class factory funcs for later use
 DMPlugin *dm_plugin_load(const char *pluginConfigPath)
@@ -204,51 +174,34 @@ DMPlugin *dm_plugin_load(const char *pluginConfigPath)
     ConfigVar cv;
 
     if (cv.readVar(pluginConfigPath, "=") > 0) {
-        if (!is_daemonised) {
-            std::cerr << thread_id << "Unable to load plugin config: " << pluginConfigPath << std::endl;
-        }
-        syslog(LOG_ERR, "Unable to load plugin config %s", pluginConfigPath);
+        E2LOGGER_error("Unable to load plugin config: ", pluginConfigPath);
         return NULL;
     }
 
     String plugname(cv["plugname"]);
 
     if (plugname.length() < 1) {
-        if (!is_daemonised) {
-            std::cerr << thread_id << "Unable read plugin config plugname variable: " << pluginConfigPath << std::endl;
-        }
-        syslog(LOG_ERR, "Unable read plugin config plugname variable %s", pluginConfigPath);
+        E2LOGGER_error("Unable read plugin config plugname variable: ", pluginConfigPath);
         return NULL;
     }
 
     if (plugname == "default") {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Enabling default DM plugin" << std::endl;
-#endif
+        DEBUG_dwload("Enabling default DM plugin");
         return defaultdmcreate(cv);
     }
 
-#ifdef ENABLE_FANCYDM
+#ifdef FANCY_READY      // Plug-in not working yet
     if (plugname == "fancy") {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Enabling fancy DM plugin" << std::endl;
-#endif
+        DEBUG_dwload("Enabling fancy DM plugin");
         return fancydmcreate(cv);
     }
 #endif
 
-#ifdef ENABLE_TRICKLEDM
     if (plugname == "trickle") {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Enabling trickle DM plugin" << std::endl;
-#endif
+        DEBUG_dwload("Enabling trickle DM plugin");
         return trickledmcreate(cv);
     }
-#endif
 
-    if (!is_daemonised) {
-        std::cerr << thread_id << "Unable to load plugin: " << plugname << std::endl;
-    }
-    syslog(LOG_ERR, "Unable to load plugin %s", plugname.toCharArray());
+    E2LOGGER_error("Unable to load plugin: ", plugname);
     return NULL;
 }
