@@ -7,26 +7,23 @@
 // INCLUDES
 
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 #include "HTMLTemplate.hpp"
 #include "RegExp.hpp"
 #include "String.hpp"
 #include "OptionContainer.hpp"
+#include "Logger.hpp"
 
 #include <cstdlib>
 #include <cstdio>
 #include <unistd.h>
-#include <syslog.h>
-//#include <istream>
 #include <iostream>
 #include <fstream>
 
 // GLOBALS
 
-extern bool is_daemonised;
 extern OptionContainer o;
-extern thread_local std::string thread_id;
 
 // IMPLEMENTATION
 
@@ -51,17 +48,14 @@ bool HTMLTemplate::readTemplateFile(const char *filename, const char *placeholde
     RegExp re;
     // compile regexp for matching supported placeholders
     // allow optional custom placeholder string
-    re.comp(placeholders ? placeholders : "-URL-|-REASONGIVEN-|-REASONLOGGED-|-USER-|-IP-|-HOST-|-FILTERGROUP-|-RAWFILTERGROUP-|-BYPASS-|-CATEGORIES-|-SHORTURL-|-SERVERIP-");
+    re.comp(placeholders ? placeholders : "-URL-|-REASONGIVEN-|-REASONLOGGED-|-USER-|-IP-|-HOST-|-FILTERGROUP-|-RAWFILTERGROUP-|-BYPASS-|-CATEGORIES-|-SHORTURL-|-SERVERIP-|-EXTFLAGS-|-SERVERNAME-");
     RegResult Rre;
     unsigned int offset;
     String result;
     String line;
     std::ifstream templatefile(filename, std::ios::in); // e2guardian.conf
     if (!templatefile.good()) {
-        if (!is_daemonised) {
-            std::cerr << thread_id << "error reading: " << filename << std::endl;
-        }
-        syslog(LOG_ERR,"error reading HTML template file: %s", filename);
+        E2LOGGER_error("error reading HTML template file: ", filename);
         return false;
     }
     while (!templatefile.eof()) {
@@ -88,11 +82,15 @@ bool HTMLTemplate::readTemplateFile(const char *filename, const char *placeholde
             push(line);
         }
     }
-    if (html.size() < 0) {
-	syslog(LOG_ERR, "Unable to parse template file: %s", filename);
+    if (html.size() < 1) {
+	    E2LOGGER_error("Unable to parse template file: ", filename);
         return false;
     }
 
+    // add space as last line - to make safe i+1 and size -1 logic in display_hb
+    line = " ";
+    push(line);
+
     templatefile.close();
     return true;
 }
@@ -107,29 +105,33 @@ void makeURLSafe(String &url)
 }
 
 void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, std::string &logreason, std::string &categories,
-                           std::string *user, std::string *ip, std::string *host, int filtergroup, String grpname, String &hashed , String &localip) {
-#ifdef DGDEBUG
-    std::cerr << thread_id << "Displaying TEMPLATE" << std::endl;
-#endif
+                           std::string *user, std::string *ip, std::string *host, int filtergroup, String grpname, String &hashed , String &localip, String &extflags) {
+
+    DEBUG_debug("Displaying TEMPLATE. url:", url, " reason:", reason, " logreason:", logreason);
+
     String line;
     bool newline;
-    unsigned int sz = html.size() - 1; // the last line can have no thingy. erm... carriage return?
+    unsigned int sz = html.size();
+    if (sz < 1)   //template is empty
+        return;
+    sz--;           //ignore last space line added by read function
     String safeurl(*url); // Take a copy of the URL so we can encode it to stop XSS
     bool safe = false;
+    String servername("");
+    servername = o.net.server_name;
     for (unsigned int i = 0; i < sz; i++) {
-        // preserve newlines from original file
-	//
+        // preserve newlines from original file	    
         newline = false;
         line = html[i];
-#ifdef DGDEBUG
-    	std::cerr << thread_id << "Displaying TEMPLATE: " <<  line.c_str() << std::endl;
-#endif
-	// Take care SSLMITM negotiation error
-	if (line.length() < 1){
-    		ebody += "\n";
-		syslog(LOG_ERR, "Corrupted TEMPLATE returns: %s", url->c_str());
-		break;
-	}
+    	DEBUG_debug("Displaying TEMPLATE: ", line);
+
+        // Take care SSLMITM negotiation error
+        if (line.length() < 1){
+            ebody += "\n";
+            E2LOGGER_error("Corrupted TEMPLATE returns: ", url->c_str());
+            break;
+        }
+
         // look for placeholders (split onto their own line by readTemplateFile) and replace them
         if (line == "-URL-") {
             if (!safe) {
@@ -155,6 +157,8 @@ void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, s
             line = safereason;
         } else if (line == "-REASONLOGGED-") {
             line = logreason;
+        } else if (line == "-SERVERNAME-") {
+            line = servername;
         } else if (line == "-USER-") {
             String safeuser(*user);
             makeURLSafe(safeuser);
@@ -163,14 +167,6 @@ void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, s
             line = *ip;
         } else if (line == "-HOST-") {
             if (host == NULL) {
-//#ifdef DGDEBUG
-                //std::cerr << thread_id << "-HOST- placeholder encountered but hostname currently unknown; lookup forced." << std::endl;
-//#endif
-                //std::deque<String> *names = ipToHostname(ip->c_str());
-                //if (names->size() > 0) {
-                    //*host = names->front();
-                //}
-                //delete names;
                 line = "";
             } else {
                 line = *host;
@@ -187,7 +183,11 @@ void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, s
             }
         } else if (line == "-BYPASS-") {
             if (hashed.length() > 0) {
-                line = *url;
+                if (!safe) {
+                    makeURLSafe(safeurl);
+                    safe = true;
+                }
+                line = safeurl;
                 if (!(url->after("://").contains("/"))) {
                     line += "/";
                 }
@@ -199,6 +199,8 @@ void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, s
             } else {
                 line = "";
             }
+        } else if (line == "-EXTFLAGS-") {
+	        line = extflags;
         } else {
             // if this line wasn't a placeholder, and neither is the
             // next line, then output a newline, thus preserving line breaks
@@ -214,13 +216,14 @@ void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, s
             ebody += "\n";
         }
     }
-    ebody += html[sz].toCharArray();
-    ebody += "\n";
+    //ebody += html[sz].toCharArray();   - no longer needed as html[sz] is added as padding
+    //ebody += "\n";
 }
 
+#ifdef NOTDEF
 // fill in placeholders with the given information and send the resulting page to the client
 // only useful if you used the default set of placeholders
-    void HTMLTemplate::display(Socket *s, String *url, std::string &reason, std::string &logreason, std::string &categories,
+void HTMLTemplate::display(Socket *s, String *url, std::string &reason, std::string &logreason, std::string &categories,
                                std::string *user, std::string *ip, std::string *host, int filtergroup, String grpname, String &hashed)
 {
     String ebody;
@@ -229,3 +232,4 @@ void HTMLTemplate::display_hb(String &ebody, String *url, std::string &reason, s
                                user, ip, host, filtergroup, grpname, hashed, localip);
     s->writeString(ebody.toCharArray());
 }
+#endif
