@@ -5,11 +5,11 @@
 // INCLUDES
 
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 #include "ImageContainer.hpp"
+#include "Logger.hpp"
 
-#include <syslog.h>
 #include <iostream>
 #include <fstream>
 #include <stdexcept>
@@ -19,8 +19,6 @@
 
 // GLOBALS
 
-extern bool is_daemonised;
-extern thread_local std::string thread_id;
 
 // IMPLEMENTATION
 
@@ -48,10 +46,7 @@ void ImageContainer::reset()
 //void ImageContainer::display(Socket *s)
 bool ImageContainer::display(Socket *s)
 {
-#ifdef DGDEBUG
-    std::cerr << thread_id << "Displaying custom image file" << std::endl;
-    std::cerr << thread_id << "mimetype: " << mimetype << std::endl;
-#endif
+    DEBUG_debug("Displaying custom image file mimetype: ", mimetype);
     s->writeString("Content-type: ");
     s->writeString(mimetype.toCharArray());
     s->writeString("\n\n");
@@ -99,21 +94,13 @@ bool ImageContainer::read(const char *filename)
         image = new char[imagelength + 1];
         imagefile.read(image, imagelength);
         if (!imagefile.good()) {
-            if (!is_daemonised)
-                std::cerr << thread_id << "Error reading custom image file: " << filename << std::endl;
-            syslog(LOG_ERR, "%s", "Error reading custom image file.");
+            E2LOGGER_error("Error reading custom image file: ", filename);
             return false;
         }
     } else {
-        if (!is_daemonised)
-            std::cerr << thread_id << "Error reading custom image file: " << filename << std::endl;
-        syslog(LOG_ERR, "%s", "Error reading custom image file.");
+        E2LOGGER_error("Error reading custom image file: ", filename);
         return false;
     }
     imagefile.close();
-    //    #ifdef DGDEBUG
-    //      for (long int i = 0; i < imagelength; i++)
-    //          printf("Image byte content: %x\n", image[i]);
-    //    #endif
     return true;
 }
