@@ -7,13 +7,14 @@
 // INCLUDES
 
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 #include "RegExp.hpp"
+#include "Logger.hpp"
+
 #include <cstring>
 #include <iostream>
 
-extern thread_local std::string thread_id;
 
 RegResult::RegResult()
     : imatched(false)
@@ -120,18 +121,12 @@ bool RegExp::comp(const char *exp)
         regfree(&reg);
         wascompiled = false;
     }
-#ifdef DGDEBUG
-    std::cerr << thread_id << "Compiling " << exp << std::endl;
-#endif
+    DEBUG_regexp("Compiling ", exp);
 #ifdef HAVE_PCRE
-#ifdef DGDEBUG
-    std::cerr << thread_id << "...with PCRE " << std::endl;
-#endif
+    DEBUG_regexp("...with PCRE ");
     if (regcomp(&reg, exp, REG_ICASE | REG_EXTENDED | REG_DOTALL) != 0) { // compile regex
 #else
-#ifdef DGDEBUG
-    std::cerr << thread_id << "...without PCRE " << std::endl;
-#endif
+    DEBUG_regexp("...without PCRE ");
     if (regcomp(&reg, exp, REG_ICASE | REG_EXTENDED) != 0) {
 #endif
         regfree(&reg);
@@ -146,6 +141,11 @@ bool RegExp::comp(const char *exp)
 // match the given text against the pre-compiled expression
 bool RegExp::match(const char *text, RegResult &rs)
 {
+    rs.results.clear();
+    rs.offsets.clear();
+    rs.lengths.clear();
+    rs.imatched = false;
+
     if (!wascompiled) {
         return false; // need exception?
     }
@@ -155,10 +155,6 @@ bool RegExp::match(const char *text, RegResult &rs)
 
     char *pos = (char *)text;
     int i;
-    rs.results.clear();
-    rs.offsets.clear();
-    rs.lengths.clear();
-    rs.imatched = false;
     unsigned int num_sub_expressions = MAX_SUB_EXPRESSIONS;
     if (reg.re_nsub < num_sub_expressions)
         num_sub_expressions = reg.re_nsub;
@@ -172,9 +168,7 @@ bool RegExp::match(const char *text, RegResult &rs)
     if (regexec(&reg, pos, num_sub_expressions + 1, pmatch, 0)) { // run regexdelete[]pmatch;
         delete[] pmatch;
         rs.imatched = false;
-#ifdef REDEBUG
-            std::cerr << thread_id << "no match for:" << searchstring << std::endl;
-#endif
+        DEBUG_regexp("no match for:", searchstring);
         return false; // if no match
     }
     size_t matchlen;
@@ -207,9 +201,7 @@ bool RegExp::match(const char *text, RegResult &rs)
     }
     rs.imatched = true;
     delete[] pmatch;
-#ifdef REDEBUG
-    std::cerr << thread_id << "match(s) for:" << searchstring << std::endl;
-#endif
+    DEBUG_regexp("match(s) for:", searchstring);
     return true; // match(s) found
 }
 
