@@ -14,10 +14,8 @@
 #include <sstream>
 #include <iomanip>
 
-#ifdef __SSLMITM
 #include "openssl/ssl.h"
 #include "String.hpp"
-#endif
 
 // DECLARATIONS
 
@@ -53,25 +51,42 @@ class Socket : public BaseSocket
     int getPeerSourcePort();
     int getPort();
     void setPort(int port);
+    void setClientAddr( std::string ip, int port);
     unsigned long int getPeerSourceAddr();
 
+    std::string down_thread_id;
+
     // get local IP
     std::string getLocalIP();
     int getLocalPort();
 
     // Chunked i/o
     String chunked_trailer;
-    int chunk_to_read;
+    long int chunk_to_read;
     bool writeChunk( char *buffout, int len, int timeout);
     bool writeChunkTrailer( String &trailer);
     int readChunk( char *buffout, int maxlen, int timeout);
     int loopChunk(int timeout);
     int drainChunk(int timeout);
     void resetChunk();
+    short int get_wait_flag(bool write_flag);
+
+    //flags for use with ssl only
+    bool s_read_wants_read = false;
+    bool s_read_wants_write = false;
+    bool s_write_wants_read = false;
+    bool s_write_wants_write = false;
+    bool s_shutdown_wants_read = false;
+    bool s_shutdown_wants_write = false;
+    int s_pending = 0;
+    bool s_has_pending = false;
+    bool s_prev_has_pending = false;
+
+    bool s_checkPending();
+    int s_checkShutdown();
 
     bool chunkError;
 
-#ifdef __SSLMITM
     //use this socket as an ssl server
     int startSslClient(const std::string &certPath, String hostname);
 
@@ -93,58 +108,49 @@ class Socket : public BaseSocket
     int checkCertHostname(const std::string &hostame);
 
     void close();
-#endif //__SSLMITM
 
-#ifdef __SSLMITM
     //use this socket as an ssl server
     int startSslServer(X509 *x, EVP_PKEY *privKey, std::string &set_cipher);
 
-    // non-blocking check for writable socket
-    bool readyForOutput();
-    bool breadyForOutput(int timeout);
     // blocking check, can break on config reloads
-    void readyForOutput(int timeout, bool honour_reloadconfig = false);
+    //void readyForOutput(int timeout, bool honour_reloadconfig = false);
 
     // non-blocking check for input data
-    bool checkForInput();
-    bool bcheckForInput(int timeout);
-
-    // blocking check for data, can be told to break on signal triggered config reloads (-r)
-    void checkForInput(int timeout, bool honour_reloadconfig = false);
+    bool checkForInput(int timeout = 20);
+    //bool bcheckForInput(int timeout);
+    bool ssl_poll_wait(int eno, int timeout);
 
     // get a line from the socket - can break on config reloads
-    int getLine(char *buff, int size, int timeout, bool honour_reloadconfig = false, bool *chopped = NULL, bool *truncated = NULL) ;
+    int getLine(char *buff, int size, int timeout, bool *chopped = NULL, bool *truncated = NULL) ;
 
     // write buffer to string
     bool writeString(const char *line);
     bool writeString(std::string line);
 
-    // write buffer to string - can be told not to do an initial readyForOutput, and told to break on -r
-    bool writeToSocket(const char *buff, int len, unsigned int flags, int timeout, bool check_first = true, bool honour_reloadconfig = false);
+    // write buff to socket - blocking
+    bool writeToSocket(const char *buff, int len, unsigned int flags, int timeout);
+
+    // write buff to socket non-blocking - returns number of bytes written or 0 if would block or -1 on error
+    int writeToSocketNB(const char *buff, int len, unsigned int flags);
+
     // read from socket, returning number of bytes read
-    int readFromSocketn(char *buff, int len, unsigned int flags, int timeout);
-    // read from socket, returning error status - can be told to skip initial checkForInput, and to break on -r
-    int readFromSocket(char *buff, int len, unsigned int flags, int timeout, bool check_first = true, bool honour_reloadconfig = false);
-    // write to socket, throwing std::exception on error - can be told to break on -r
-  //  void writeToSockete(const char *buff, int len, unsigned int flags, int timeout, bool honour_reloadconfig = false) throw(std::exception);
-    void writeToSockete(const char *buff, int len, unsigned int flags, int timeout, bool honour_reloadconfig = false);
-#endif //__SSLMITM
+    int readFromSocket(char *buff, int len, unsigned int flags, int timeout, bool ret_part = false);
+
     bool getIeof();
 
     private:
-#ifdef __SSLMITM
     SSL *ssl = NULL;
     SSL_CTX *ctx = NULL;
     bool isssl = false;
     bool issslserver = false;
-#else
-    bool isssl = false;
-#endif //__SSLMITM
 
     // local & remote addresses
     struct sockaddr_in my_adr;
     struct sockaddr_in peer_adr;
-    int my_port;
+    int my_port = 0;
+    std::string my_addr;
+    int client_port = 0;
+    std::string client_addr;
     bool ieof = false;
 };
 
