@@ -7,19 +7,17 @@
 // INCLUDES
 
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 #include "SocketArray.hpp"
 #include "Queue.hpp"
+#include "Logger.hpp"
 
-#include <syslog.h>
 #include <cerrno>
 #include <cstring>
 
 // GLOBALS
 
-extern bool is_daemonised;
-extern thread_local std::string thread_id;
 
 // IMPLEMENTATION
 
@@ -50,9 +48,7 @@ int SocketArray::bindSingle(int port)
     if (socknum < 1) {
         return -1;
     }
-#ifdef DGDEBUG
-    std::cerr << thread_id << "bindSingle binding port" << port << std::endl;
-#endif
+    DEBUG_debug("bindSingle binding port", port);
     lc_types.push_back(CT_PROXY);
     return drawer[0].bind(port);
 }
@@ -62,34 +58,26 @@ int SocketArray::bindSingle(unsigned int index, int port, unsigned int type)
     if (socknum <= index) {
         return -1;
     }
-#ifdef DGDEBUG
-    std::cerr << thread_id << "bindSingle binding port" << port  << " with type " << type << std::endl;
-#endif
+    DEBUG_debug("bindSingle binding port", port, " with type ", type);
     lc_types.push_back(type);
     return drawer[index].bind(port);
 }
 
 
 // bind our first socket to any IP and one or more ports
-int SocketArray::bindSingleM(std::deque<String> &ports)
+int SocketArray::bindSingleM(std::deque<String> &ports, int &index, int ct_type )
 {
-    if (socknum < ports.size()) {
+    if ( socknum < (index + ports.size())) {
         return -1;
     }
-    for (unsigned int i = 0; i < ports.size(); i++) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "bindSingleM binding port" << ports[i] << std::endl;
-#endif
-        if (drawer[i].bind(ports[i].toInteger())) {
-            if (!is_daemonised) {
-                std::cerr << thread_id << "Error binding server socket: ["
-                          << ports[i] << " " << i << "] (" << strerror(errno) << ")" << std::endl;
-            }
-            String p = ports[i];
-            syslog(LOG_ERR, "Error binding socket: [%s %d] (%s)", p.toCharArray(), i, strerror(errno));
+    for (auto i : ports) {
+        DEBUG_debug("bindSingleM binding port", i);
+        if (drawer[index].bind(i.toInteger())) {
+            E2LOGGER_error("Error binding server socket: [", i, " ", index, "] (", strerror(errno), ")");
             return -1;
         }
-        lc_types.push_back(CT_PROXY);
+        lc_types.push_back(ct_type);
+        index++;
     }
     return 0;
 }
@@ -99,9 +87,7 @@ int *SocketArray::getFDAll()
 {
     int *fds = new int[socknum];
     for (unsigned int i = 0; i < socknum; i++) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Socket " << i << " fd:" << drawer[i].getFD() << std::endl;
-#endif
+        DEBUG_debug("Socket ", i, " fd:", drawer[i].getFD() );
         fds[i] = drawer[i].getFD();
     }
     return fds;
@@ -112,10 +98,7 @@ int SocketArray::listenAll(int queue)
 {
     for (unsigned int i = 0; i < socknum; i++) {
         if (drawer[i].listen(queue)) {
-            if (!is_daemonised) {
-                std::cerr << thread_id << "Error listening to socket" << std::endl;
-            }
-            syslog(LOG_ERR, "%s", "Error listening to socket");
+            E2LOGGER_error("Error listening to socket");
             return -1;
         }
     }
@@ -123,25 +106,23 @@ int SocketArray::listenAll(int queue)
 }
 
 // bind all sockets to given IP list
-int SocketArray::bindAll(std::deque<String> &ips, std::deque<String> &ports)
+int SocketArray::bindAll(std::deque<String> &ips, std::deque<String> &ports, int &index, int ct_type)
 {
-    if (ips.size() > socknum) {
+    if ((index + (ips.size() * ports.size())) > socknum) {
         return -1;
     }
     //for (unsigned int i = 0; i < socknum; i++) {
-    for (unsigned int i = 0; i < ips.size(); i++) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Binding server socket[" << ports[i] << " " << ips[i] << " " << i << "])" << std::endl;
-#endif
-        if (drawer[i].bind(ips[i].toCharArray(), ports[i].toInteger())) {
-            if (!is_daemonised) {
-                std::cerr << thread_id << "Error binding server socket: ["
-                          << ports[i] << " " << ips[i] << " " << i << "] (" << strerror(errno) << ")" << std::endl;
+    for (auto i_ips : ips) {
+        for (auto i_ports : ports) {
+            DEBUG_debug("Binding server socket[", i_ports, " ", i_ips, " ", index, "]");
+            if (drawer[index].bind(i_ips.toCharArray(), i_ports.toInteger())) {
+                E2LOGGER_error("Error binding server socket: [", i_ports, " ", i_ips, " ", index, "] (", strerror(errno),
+                               ")");
+                return -1;
             }
-            syslog(LOG_ERR, "Error binding socket: [%s %s %d] (%s)", ports[i].toCharArray(), ips[i].toCharArray(), i, strerror(errno));
-            return -1;
+            lc_types.push_back(ct_type);
+            index++;
         }
-        lc_types.push_back(CT_PROXY);
     }
     return 0;
 }
