@@ -6,7 +6,7 @@
 
 // INCLUDES
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 
 #include "../String.hpp"
@@ -15,8 +15,8 @@
 #include "../UDSocket.hpp"
 #include "../OptionContainer.hpp"
 #include "../RegExp.hpp"
+#include "../Logger.hpp"
 
-#include <syslog.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -29,8 +29,6 @@
 // GLOBALS
 
 extern OptionContainer o;
-extern bool is_daemonised;
-extern thread_local std::string thread_id;
 
 // IMPLEMENTATION
 
@@ -95,16 +93,14 @@ CSPlugin *commandlinecreate(ConfigVar &definition)
 int commandlineinstance::init(void *args)
 {
     int rc;
-    if ((rc = CSPlugin::init(args)) != DGCS_OK)
+    if ((rc = CSPlugin::init(args)) != E2CS_OK)
         return rc;
 
     // read in program name
     progname = cv["progname"];
     if (progname.length() == 0) {
-        if (!is_daemonised)
-            std::cerr << thread_id << "Command-line scanner: No program specified" << std::endl;
-        syslog(LOG_ERR, "Command-line scanner: No program specified");
-        return DGCS_ERROR;
+        E2LOGGER_error("Command-line scanner: No program specified");
+        return E2CS_ERROR;
     }
 
     // split into an argument array
@@ -132,12 +128,11 @@ int commandlineinstance::init(void *args)
     }
     progname = cv["progname"];
 
-#ifdef DGDEBUG
-    std::cerr << thread_id << "Program and arguments: ";
+#ifdef DEBUG_HIGH
+    DEBUG_avscan("Program and arguments: ");
     for (int i = 0; i < numarguments; i++) {
-        std::cerr << thread_id << arguments[i] << " ";
+        DEBUG_avscan(arguments[i], ", ");
     }
-    std::cerr << thread_id << std::endl;
 #endif
 
     // read in virus name regular expression
@@ -145,10 +140,8 @@ int commandlineinstance::init(void *args)
     if (ucvirusregexp.length()) {
         usevirusregexp = true;
         if (!virusregexp.comp(ucvirusregexp.toCharArray())) {
-            if (!is_daemonised)
-                std::cerr << thread_id << "Command-line scanner: Could not compile regular expression for extracting virus names" << std::endl;
-            syslog(LOG_ERR, "Command-line scanner: Could not compile regular expression for extracting virus names");
-            return DGCS_ERROR;
+            E2LOGGER_error("Command-line scanner: Could not compile regular expression for extracting virus names");
+            return E2CS_ERROR;
         }
         String ssubmatch(cv["submatch"]);
         if (ssubmatch.length())
@@ -164,14 +157,10 @@ int commandlineinstance::init(void *args)
     tempcodes[sinfectedcodes.length()] = '\0';
     strncpy(tempcodes, sinfectedcodes.c_str(), sinfectedcodes.length());
     result = strtok(tempcodes, ",");
-#ifdef DGDEBUG
-    std::cerr << thread_id << "Infected file return codes: ";
-#endif
+    DEBUG_avscan("Infected file return codes: ");
     while (result) {
         tempinfectedcodes.push_back(atoi(result));
-#ifdef DGDEBUG
-        std::cerr << thread_id << tempinfectedcodes.back() << " ";
-#endif
+        DEBUG_avscan(tempinfectedcodes.back() );
         result = strtok(NULL, ",");
     }
     delete[] tempcodes;
@@ -179,31 +168,22 @@ int commandlineinstance::init(void *args)
     tempcodes[scleancodes.length()] = '\0';
     strncpy(tempcodes, scleancodes.c_str(), scleancodes.length());
     result = strtok(tempcodes, ",");
-#ifdef DGDEBUG
-    std::cerr << thread_id << std::endl
-              << "Clean file return codes: ";
-#endif
+    
+    DEBUG_avscan("Clean file return codes: ");
     while (result) {
         tempcleancodes.push_back(atoi(result));
-#ifdef DGDEBUG
-        std::cerr << thread_id << tempcleancodes.back() << " ";
-#endif
+        DEBUG_avscan(tempcleancodes.back());
         result = strtok(NULL, ",");
     }
     delete[] tempcodes;
-#ifdef DGDEBUG
-    std::cerr << thread_id << std::endl;
-#endif
 
     // we need at least one of our three mechanisms (cleancodes, infectedcodes and virus names)
     // to be defined in order to make a decision about the nature of a scanning result.
     numcleancodes = tempcleancodes.size();
     numinfectedcodes = tempinfectedcodes.size();
     if (!(usevirusregexp || numcleancodes || numinfectedcodes)) {
-        if (!is_daemonised)
-            std::cerr << thread_id << "Command-line scanner requires some mechanism for interpreting results. Please define cleancodes, infectedcodes, and/or a virusregexp." << std::endl;
-        syslog(LOG_ERR, "Command-line scanner requires some mechanism for interpreting results. Please define cleancodes, infectedcodes, and/or a virusregexp.");
-        return DGCS_ERROR;
+        E2LOGGER_error("Command-line scanner requires some mechanism for interpreting results. Please define cleancodes, infectedcodes, and/or a virusregexp.");
+        return E2CS_ERROR;
     }
 
     // Copy return code lists out into static arrays
@@ -226,14 +206,12 @@ int commandlineinstance::init(void *args)
         } else if (sdefaultresult == "infected") {
             defaultresult = 0;
         } else {
-            if (!is_daemonised)
-                std::cerr << thread_id << "Command-line scanner: Default result value not understood" << std::endl;
-            syslog(LOG_ERR, "Command-line scanner: Default result value not understood");
-            return DGCS_WARNING;
+            E2LOGGER_error("Command-line scanner: Default result value not understood");
+            return E2CS_WARNING;
         }
     }
 
-    return DGCS_OK;
+    return E2CS_OK;
 }
 
 // no need to replace the inheritied scanMemory() which just calls scanFile()
@@ -249,19 +227,17 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
     int scannerstderr[2];
     if (socketpair(AF_UNIX, SOCK_STREAM, 0, scannerstdout) == -1) {
         lastmessage = "Cannot create sockets for communicating with scanner";
-        syslog(LOG_ERR, "Cannot open socket pair for command-line scanner's stdout: %s", strerror(errno));
-        return DGCS_SCANERROR;
+        E2LOGGER_error(lastmessage, " ", strerror(errno) );
+        return E2CS_SCANERROR;
     }
     if (socketpair(AF_UNIX, SOCK_STREAM, 0, scannerstderr) == -1) {
-        lastmessage = "Cannot create sockets for communicating with scanner";
-        syslog(LOG_ERR, "Cannot open socket pair for command-line scanner's stderr: %s", strerror(errno));
-        return DGCS_SCANERROR;
+        lastmessage = "Cannot create sockets for communicating with scanner" ;
+        E2LOGGER_error(lastmessage, " ", strerror(errno) );
+        return E2CS_SCANERROR;
     }
     int f = fork();
     if (f == 0) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Running: " << progname.toCharArray() << " " << filename << std::endl;
-#endif
+        DEBUG_avscan("Running: ", progname, " ", filename);
         // close read ends of sockets
         close(scannerstdout[0]);
         close(scannerstderr[0]);
@@ -272,12 +248,12 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
         arguments[numarguments] = (char *)filename;
         execv(arguments[0], arguments);
         // if we get here, an error occurred!
-        syslog(LOG_ERR, "Cannot exec command-line scanner (command \"%s %s\"): %s", progname.toCharArray(), filename, strerror(errno));
+        E2LOGGER_error("Cannot exec command-line scanner (command ", progname, "  ",filename, "): ", strerror(errno));
         _exit(255);
     } else if (f == -1) {
         lastmessage = "Cannot launch scanner";
-        syslog(LOG_ERR, "Cannot fork to launch command-line scanner (command \"%s %s\"): %s", progname.toCharArray(), filename, strerror(errno));
-        return DGCS_SCANERROR;
+        E2LOGGER_error("Cannot fork to launch command-line scanner (command ", progname, "  ",filename, "): ", strerror(errno));
+        return E2CS_SCANERROR;
     }
 
     // close write ends of sockets
@@ -288,7 +264,7 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
     std::string result;
     FILE *readme = fdopen(scannerstdout[0], "r");
     while (fgets(buff, 8192, readme) != NULL) {
-#ifndef DGDEBUG
+#ifndef DEBUG_LOW
         if (usevirusregexp)
 #endif
             result += buff;
@@ -296,7 +272,7 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
     fclose(readme);
     readme = fdopen(scannerstderr[0], "r");
     while (fgets(buff, 8192, readme) != NULL) {
-#ifndef DGDEBUG
+#ifndef DEBUG_LOW
         if (usevirusregexp)
 #endif
             result += buff;
@@ -313,21 +289,15 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
 
     if (waitpid(f, &returncode, 0) == -1) {
         lastmessage = "Cannot get scanner return code";
-        syslog(LOG_ERR, "Cannot get command-line scanner return code: %s", strerror(errno));
-        return DGCS_SCANERROR;
+        E2LOGGER_error(lastmessage, " ", strerror(errno));
+        return E2CS_SCANERROR;
     }
 
-#ifdef DGDEBUG
-    std::cerr << thread_id << "Scanner result" << std::endl
-              << "--------------" << std::endl
-              << result << std::endl
-              << "--------------" << std::endl
-              << "Code: " << returncode << std::endl;
-#endif
+    DEBUG_avscan("Scanner result: ", (result), "Code: ", returncode);
     if (returncode == 255) {
         lastmessage = "Cannot get scanner return code";
-        syslog(LOG_ERR, "Cannot get command-line scanner return code: scanner exec failed");
-        return DGCS_SCANERROR;
+        E2LOGGER_error("Cannot get command-line scanner return code: scanner exec failed");
+        return E2CS_SCANERROR;
     }
 
     lastvirusname = "Unknown";
@@ -337,14 +307,14 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
         if (virusregexpres.matched()) {
             lastvirusname = virusregexpres.result(submatch);
             blockFile(NULL, NULL, checkme);
-            return DGCS_INFECTED;
+            return E2CS_INFECTED;
         }
     }
 
     if (cleancodes) {
         for (int i = 0; i < numcleancodes; i++) {
             if (returncode == cleancodes[i])
-                return DGCS_CLEAN;
+                return E2CS_CLEAN;
         }
     }
 
@@ -352,19 +322,19 @@ int commandlineinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *dochead
         for (int i = 0; i < numinfectedcodes; i++) {
             if (returncode == infectedcodes[i]) {
                 blockFile(NULL, NULL, checkme);
-                return DGCS_INFECTED;
+                return E2CS_INFECTED;
             }
         }
     }
 
     if (defaultresult == 1)
-        return DGCS_CLEAN;
+        return E2CS_CLEAN;
     else if (defaultresult == 0) {
         blockFile(NULL, NULL, checkme);
-        return DGCS_INFECTED;
+        return E2CS_INFECTED;
     }
 
     if (returncode != 0)
-        return DGCS_SCANERROR;
+        return E2CS_SCANERROR;
     return 0;
 }
